From: Junio C Hamano Date: Sun, 27 Jan 2013 05:32:07 GMT Subject: Re: [PATCH 0/3] lazily load commit->buffer Message-ID: <7vtxq3xkbs.fsf@alter.siamese.dyndns.org> In-Reply-To: <20130126221400.GA13827@sigill.intra.peff.net> Jeff King writes: > My HEAD has about 400/3000 non-unique commits, which matches your > numbers percentage-wise. Dropping the lines above (and always freeing) > takes my best-of-five for "git log -g" from 0.085s to 0.080s. Which is > well within the noise. Doing "git log -g Makefile" ended up at 0.183s > both before and after. > > ... I'd be in favor of > dropping the lines just to decrease complexity of the code. I think we are in agreement, then.